<?php
/*
Plugin Name: Ads In Posts
plugin URI:
Description:
version: 1.1.1
Author: 99 Robots
Author URI: https://99robots.com
License: GPL2
*/

// Exit if accessed directly

if ( !defined( 'ABSPATH' ) ) exit;

if ( !class_exists('NNR_Ads_In_Posts') ) :

// Set default timezone

date_default_timezone_set(timezone_name_from_abbr(null, (int) get_option('gmt_offset') * 3600 , true));

register_activation_hook( __FILE__, 	array('NNR_Ads_In_Posts', 'register_activation'));
add_action('admin_menu', 				array('NNR_Ads_In_Posts', 'menu'));
add_action('init', 						array('NNR_Ads_In_Posts', 'load_textdoamin'));
add_action('the_content',				array('NNR_Ads_In_Posts', 'display_content'), 10, 1);
add_shortcode('nnr_ads_in_posts', 		array('NNR_Ads_In_Posts', 'shortcode'));

// Include all the helper libraries

require_once('includes/data-manager/autoload.php');
require_once('includes/display-conditions/autoload.php');
require_once('includes/stats-tracker/autoload.php');

/**
 * NNR_Ads_In_Posts class.
 */
class NNR_Ads_In_Posts {

	/**
	 * prefix
	 *
	 * (default value: 'nnr_ads_in_posts_')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $prefix = 'nnr_ads_in_posts_';

	/**
	 * prefix_dash
	 *
	 * (default value: 'nnr-aip-')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $prefix_dash = 'nnr-aip-';

	/**
	 * text_domain
	 *
	 * (default value: '99robots-ads-in-posts')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $text_domain = '99robots-ads-in-posts';

	/**
	 * dashboard_page
	 *
	 * (default value: 'nnr-aip-dashbaord')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $dashboard_page = 'nnr-aip-dashboard';

	/**
	 * add_edit_page
	 *
	 * (default value: 'nnr-aip-add-edit')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $add_edit_page = 'nnr-aip-add-edit';

	/**
	 * updates_page
	 *
	 * (default value: 'nnr-aip-updates')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $updates_page = 'nnr-aip-updates';

	/**
	 * stats_page
	 *
	 * (default value: 'nnr-aip-stats')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $stats_page = 'nnr-aip-stats';

	/**
	 * data_manager_table_name
	 *
	 * (default value: 'nnr_ads_in_posts')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $data_manager_table_name = 'nnr_ads_in_posts';

	/**
	 * stats_table_name
	 *
	 * (default value: 'nnr_ads_in_posts_stats')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $stats_table_name = 'nnr_ads_in_posts_stats';

	/**
	 * Returns a default Ad
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function default_data() {
		return array(
			'name'					=> __('My Ad', self::$text_domain),
			'active'				=> 0,
			'start_date'			=> date('Y-m-d H:i:s', mktime(0, 0, 0, date("m"), date("d"), date("Y"))),
			'end_date'				=> date("Y-m-d H:i:s", mktime(0, 0, 0, date("m"), date("d"), date("Y")+20)),
			'display_conditions'	=> array(
				'sitewide'			=> false,
				'post_types'		=> array(
					'post'			=> array(
						'type'		=> 'all',
					)
				)
			),
			'args'					=> array(
				'content_type'		=> 'ad',
				'powered_by'		=> true,
			),
		);
	}

	/**
	 * Load the text domain
	 *
	 * @since 1.0.0
	 */
	static function load_textdoamin() {
		load_plugin_textdomain(self::$text_domain, false, basename( dirname( __FILE__ ) ) . '/languages' );
	}

	/**
	 * Performs tasks needed upon activation
	 *
	 * @since 1.0.0
	 */
	static function register_activation() {

		// Check if multisite, if so then save as site option

		if ( function_exists('is_multisite') && is_multisite() ) {
			update_site_option(self::$prefix . 'version', NNROBOTS_ADS_IN_POSTS_VERSION_NUM);
		} else {
			update_option(self::$prefix . 'version', NNROBOTS_ADS_IN_POSTS_VERSION_NUM);
		}

		// Create Table upon activation

		$data_manager = new NNR_Data_Manager_v1( self::$data_manager_table_name );
		$data_manager->create_table();

		$stats_tracker = new NNR_Stats_Tracker_v1( self::$stats_table_name );
		$stats_tracker->create_table();

	}

	/**
	 * Hooks to 'plugin_action_links_' filter
	 *
	 * @since 1.0.0
	 */
	static function settings_link($links) {
		$settings_link = '<a href="admin.php?page=' . self::$dashboard_page . '">' . __('Overlays', self::$text_domain) . '</a>';
		array_unshift($links, $settings_link);
		return $links;
	}

	/**
	 * Outputs the Ad inside the post
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function display_content($content) {

		if ( !is_singular() ) {
			return $title;
		}

		global $post;

		$now = date('Y-m-d h:m:s');

		$data_manager = new NNR_Data_Manager_v1( self::$data_manager_table_name );
		$data = $data_manager->get_data_from_date_range($now, $now);
		$display_manager = new NNR_Display_Conditions_Display_v2();

		foreach ( $data as $item ) {
			if ( $display_manager->check_conditions($item['display_conditions']) ) {

				// Top of Post

				if ( $item['args']['placement'] == 'top' ) {
					$content = self::display_ad($item) . $content;
				}

				// Bottom of  Post

				else if ( $item['args']['placement'] == 'bottom' ) {
					$content .= self::display_ad($item);
				}

				// After x Paragraphs

				else if ( $item['args']['placement'] == 'paragraphs' ) {
					$content = self::display_ad($item) . $content;
				}

				// Manual Display

				else if ( $item['args']['placement'] == 'manual' ) {
					$content .= self::display_ad($item);
				}
			}
		}

		return $content;

	}

	/**
	 * Display the Ad from shortcode
	 *
	 * @access public
	 * @static
	 * @param mixed $atts
	 * @return void
	 */
	static function shortcode($atts) {

		// Return nothing if this is not a single post

		if ( !is_singular() ) {
			return null;
		}

		$args = shortcode_atts( array(
	        'id' => -1,
	    ), $atts );

	    $data_manager = new NNR_Data_Manager_v1( self::$data_manager_table_name );
		$data = $data_manager->get_data_from_id( $args['id'] );

		return self::display_ad($data);
	}

	/**
	 * Display a specific Ad
	 *
	 * @access public
	 * @static
	 * @param mixed $data_id
	 * @return void
	 */
	static function display_ad( $data ){

		// Powered By

		$powered_by = '';

		if ( isset($data['args']['powered_by']) && $data['args']['powered_by'] ) {
			$powered_by = '<a class="' . self::$prefix_dash . 'powered-by" href="https://99robots.com/?post_type=download&p=10690" target="_blank" >' . __('Powered By Ads In Posts', self::$text_domain) . '</a>';
		}

		$code = '<div class="' . self::$prefix_dash . 'wrap" data-id="' . $data['id'] . '" data-placement="' . $data['args']['placement'] . '" data-paragraphs="' . $data['args']['paragraphs'] . '">
			<div class="' . self::$prefix_dash . 'container ' . self::$prefix_dash . 'container-' . $data['args']['content_type'] . '">';

		switch($data['args']['content_type']) {

			// Self Hosted Ad

			case 'ad':

				$ad_image_src = '';

				if ( $data['args']['ad_type'] == 'image' ) {
					$ad_image_attributes = wp_get_attachment_image_src($data['args']['ad_image'], 'full');

					if( $ad_image_attributes ) {
						$ad_image_src = $ad_image_attributes[0];
					} else {
						$ad_image_src = '';
					}
				} else {
					$ad_image_src = $data['args']['ad_image_link'];
				}

				$code .= '<p>
					<a class="' . self::$prefix_dash . 'ad-link" href="' . $data['args']['ad_destination_link'] . '" target="' . $data['args']['ad_destination_target'] . '" ' . (isset($data['args']['ad_destination_rel']) && $data['args']['ad_destination_rel'] ? 'rel="nofollow"' : '') . '>
						<img src="' . $ad_image_src . '"/>
					</a>' . $powered_by . '
				</p>';

			break;

			// Third Party Ad

			case 'third-ad':

				$code .= '<p>' . html_entity_decode($data['args']['third_ad_code']) . $powered_by . '</p>';

			break;

			// Button Link

			case 'button':

				$code .= '<p>
					<a class="' . self::$prefix_dash . 'button-link" href="' . $data['args']['button_link'] . '" target="' . $data['args']['button_target'] . '" ' . (isset($item['args']['button_rel']) && $data['args']['button_rel'] ? 'rel="nofollow"' : '') . '>
						<button style="background-color:' . $data['args']['button_background_color'] . ';color:' . $data['args']['button_text_color'] . ';">' . $data['args']['button_text'] . '</button>
					</a>' . $powered_by . '
				</p>';

			break;

			default:
				$code .= '';
			break;

		}

		$code .= '</div>
		</div>';

		if ( false === ( $advanced_settings = get_option(self::$prefix_dash . 'advanced-settings') ) ) {
			$advanced_settings = array();
		}

		// Styles

		wp_enqueue_style(self::$prefix_dash . 'css', 				NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/ads-in-posts.css');
		wp_enqueue_style(self::$prefix_dash . 'fontawesome_css', 	NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/font-awesome.min.css');

		// Scripts

		wp_enqueue_script(self::$prefix_dash . 'js', 				NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/js/ads-in-posts.js');
		wp_localize_script(self::$prefix_dash . 'js', 				'nnr_aip_data', array(
			'prefix'					=> self::$prefix_dash,
			'ajaxurl'					=> admin_url('admin-ajax.php'),
			'stats_table_name'			=> self::$stats_table_name,
			'post_content_wrapper'		=> isset($advanced_settings['post_content_wrapper']) ? $advanced_settings['post_content_wrapper'] : '.entry-content',
		));

		return $code;

	}

	/**
	 * Hooks to 'admin_menu'
	 *
	 * @since 1.0.0
	 */
	static function menu() {

		// Dashboard

		add_menu_page(
			__(NNROBOTS_ADS_IN_POSTS_ITEM_NAME, self::$text_domain),	// Page Title
			__(NNROBOTS_ADS_IN_POSTS_ITEM_NAME, self::$text_domain), 	// Menu Name
	    	'manage_options', 											// Capabilities
	    	self::$dashboard_page, 										// slug
	    	array('NNR_Ads_In_Posts', 'dashboard'),						// Callback function
	    	plugin_dir_url(__FILE__) . 'img/logo.png" style="width:20px;padding-top: 6px;'
	    );

	    // Dashboard

	    $dashboard_page_load = add_submenu_page(
	    	self::$dashboard_page, 										// parent slug
	    	__('All Ads', self::$text_domain), 							// Page title
	    	__('All Ads', self::$text_domain), 							// Menu name
	    	'manage_options', 											// Capabilities
	    	self::$dashboard_page, 										// slug
	    	array('NNR_Ads_In_Posts', 'dashboard')						// Callback function
	    );
	    add_action("admin_print_scripts-$dashboard_page_load", array('NNR_Ads_In_Posts', 'dashboard_scripts'));

	    // Add / Edit

	    $add_edit_page_load = add_submenu_page(
	    	self::$dashboard_page, 										// parent slug
	    	__('Add New', self::$text_domain), 							// Page title
	    	__('Add New', self::$text_domain), 							// Menu name
	    	'manage_options', 											// Capabilities
	    	self::$add_edit_page, 										// slug
	    	array('NNR_Ads_In_Posts', 'add_edit')						// Callback function
	    );
	    add_action("admin_print_scripts-$add_edit_page_load", array('NNR_Ads_In_Posts', 'add_edit_scripts'));

	    // Stats

	    $stats_page_load = add_submenu_page(
	    	self::$dashboard_page, 										// parent slug
	    	__('Stats', self::$text_domain), 							// Page title
	    	__('Stats', self::$text_domain), 							// Menu name
	    	'manage_options', 											// Capabilities
	    	self::$stats_page, 											// slug
	    	array('NNR_Ads_In_Posts', 'stats')							// Callback function
	    );
	    add_action("admin_print_scripts-$stats_page_load", array('NNR_Ads_In_Posts', 'stats_scripts'));

	    // Updates Page

	    $updates_page_load = add_submenu_page(
	    	self::$dashboard_page, 										// parent slug
	    	__('Updates', self::$text_domain),  						// Page title
	    	__('Updates', self::$text_domain),  						// Menu name
	    	'manage_options', 											// Capabilities
	    	self::$updates_page, 										// slug
	    	array('NNR_Ads_In_Posts', 'updates')						// Callback function
	    );
	    add_action("admin_print_scripts-$updates_page_load", array('NNR_Ads_In_Posts', 'updates_scripts'));
	}

	/**
	 * Hooks to "admin_print_scripts-$page"
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function dashboard_scripts() {

		// Styles

		wp_enqueue_style(self::$prefix . 'settings_css', 					NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/settings.css');
		wp_enqueue_style(self::$prefix . 'fontawesome_css', 				NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/font-awesome.min.css');
	    wp_enqueue_style(self::$prefix . 'bootstrap_css', 					NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/nnr-bootstrap.min.css');
	    wp_enqueue_style('wp-color-picker');

		// Scripts

		wp_enqueue_script(self::$prefix . 'bootstrap_js', 					NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/js/bootstrap.min.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'admin_js', 						NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/js/dashboard.js', array('wp-color-picker', 'jquery'), false, true );
	}

	/**
	 * Hooks to "admin_print_scripts-$page"
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function add_edit_scripts() {

	    // Styles

	    wp_enqueue_style(self::$prefix . 'settings_css', 					NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/settings.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_css', 					NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/nnr-bootstrap.min.css');
		wp_enqueue_style(self::$prefix . 'fontawesome_css', 				NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/font-awesome.min.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_vertical_tabs_css',		NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/bootstrap-helpers/bootstrap.vertical-tabs.min.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_slider_css', 			NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/bootstrap-helpers/bootstrap-slider.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_iconpicker_css', 		NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/bootstrap-helpers/bootstrap-iconpicker.min.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_formhelpers_css', 		NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/bootstrap-helpers/bootstrap-formhelpers.min.css');

	    // Scripts

		wp_enqueue_media();
		wp_enqueue_script(self::$prefix . 'bootstrap_js', 					NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/js/bootstrap.min.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_slider_js', 			NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/js/bootstrap-helpers/bootstrap-slider.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_iconpicker_iconset_js',NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/js/bootstrap-helpers/iconset-fontawesome-4.2.0.min.js', array('jquery', self::$prefix . 'bootstrap_js'));
		wp_enqueue_script(self::$prefix . 'bootstrap_iconpicker_js', 		NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/js/bootstrap-helpers/bootstrap-iconpicker.js', array('jquery', self::$prefix . 'bootstrap_js', self::$prefix . 'bootstrap_iconpicker_iconset_js'));
		wp_enqueue_script(self::$prefix . 'bootstrap_formhelpers_js', 		NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/js/bootstrap-helpers/bootstrap-formhelpers.js', array('jquery'));

	    wp_enqueue_style('wp-color-picker');
	    wp_enqueue_script(self::$prefix . 'admin_add_edit_js',				NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/js/add-edit.js', array('wp-color-picker', 'jquery', 'jquery-ui-tabs', 'jquery-ui-datepicker'), false, true
	    );
	    wp_localize_script(self::$prefix . 'admin_add_edit_js', 'nnr_aip_add_edit_data', array(
		   'prefix'	=> self::$prefix_dash,
	    ));
	}

	/**
	 * Hooks to "admin_print_scripts-$page"
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function stats_scripts() {

		// Styles

		wp_enqueue_style(self::$prefix . 'settings_css', 					NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/settings.css');
	    wp_enqueue_style(self::$prefix . 'fontawesome_css', 				NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/font-awesome.min.css');
	    wp_enqueue_style(self::$prefix . 'bootstrap_css', 					NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/nnr-bootstrap.min.css');

	    // Scripts

		wp_enqueue_script(self::$prefix . 'bootstrap_js', 					NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/js/bootstrap.min.js', array('jquery'));

	}

	/**
	 * Hooks to "admin_print_scripts-$page"
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function updates_scripts(){

		wp_enqueue_style(self::$prefix . 'settings_css', 					NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/settings.css');
	    wp_enqueue_style(self::$prefix . 'fontawesome_css', 				NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/font-awesome.min.css');
	    wp_enqueue_style(self::$prefix . 'bootstrap_css', 					NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/css/nnr-bootstrap.min.css');

	    wp_enqueue_script(self::$prefix . 'updates_js', 					NNROBOTS_ADS_IN_POSTS_PLUGIN_URL . '/js/updates.js', array('jquery'));
	    wp_localize_script(self::$prefix . 'updates_js', 					'nnr_aip_updates_data', array(
			'prefix_dash' 		=> self::$prefix_dash,
			'activate_text'		=> __('Activate', self::$text_domain),
			'deactivate_text'	=> __('Deactivate', self::$text_domain),
			'no_license_key'		=> __('Please add or activate your License Key to get automatic updates.  Without a valid license key you will not receive regular updates. You can find your license key', self::$text_domain) . ' <a href="https://99robots.com/dashboard" target="_blank">here</a>',
			'expired'				=> __('EXPIRED: This license key has expired.  Please renew your license key', self::$text_domain) . ' <a href="https://99robots.com/dashboard" target="_blank">here</a>',
			'activation_error'		=> __('INVALID LICENSE KEY: The license key is not valid please try again. You can find your license key', self::$text_domain) . ' <a href="https://99robots.com/dashboard" target="_blank">here</a>.',
			'activation_valid'		=> __('SUCCESS: Your license key is valid.', self::$text_domain),
			'deactivation_valid'	=> __('SUCCESS: This site has been deactivated.', self::$text_domain),
			'deactivation_error'	=> __('DEACTIVATION FAILED: This site could not be deactivated.', self::$text_domain),
		));

	}

	/**
	 * Display the Dashboard page
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function dashboard() {

		include_once(NNROBOTS_ADS_IN_POSTS_PLUGIN_DIR . 'controllers/dashboard.php');

	}

	/**
	 * Display the Add New page
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function add_edit() {

		include_once(NNROBOTS_ADS_IN_POSTS_PLUGIN_DIR . 'controllers/add-edit.php');

	}

	/**
	 * Display the Stats page
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function stats() {

		include_once(NNROBOTS_ADS_IN_POSTS_PLUGIN_DIR . 'controllers/stats.php');

	}

	/**
	 * Display the Updates page
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function updates() {

		include_once(NNROBOTS_ADS_IN_POSTS_PLUGIN_DIR . 'controllers/updates.php');

	}

	/**
	 * Perform all the actions with a license
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function license_action() {

		if ( !isset($_POST['license_key']) ) {
			echo '';
			die();
		}

		// data to send in our API request

		$api_params = array(
			'edd_action'	=> $_POST['license_action'],
			'license' 		=> $_POST['license_key'],
			'item_name' 	=> urlencode( NNROBOTS_ADS_IN_POSTS_ITEM_NAME ), // the name of our product in EDD
			'url'       	=> is_multisite() ? network_home_url() : home_url()
		);

		// Call the custom API.

		$response = wp_remote_post( NNROBOTS_ADS_IN_POSTS_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

		// make sure the response came back okay

		if ( is_wp_error( $response ) ) {
			echo $response;
			die();
		}

		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		if ( $_POST['license_action'] == 'activate_license' ) {
			self::update_license_key($_POST['license_key']);
		} else if ( $_POST['license_action'] == 'deactivate_license' && $license_data->license == 'deactivated') {
			self::update_license_key('');
		}

		// decode the license data

		echo $license_data->license;

		die();

	}

	/**
	 * Check if license key is active
	 *
	 * @access public
	 * @static
	 * @param mixed $license_key
	 * @return void
	 */
	static function is_license_active( $license_key ) {

		if ( !isset( $license_key ) ) {
			return false;
		}

		// data to send in our API request

		$api_params = array(
			'edd_action'	=> 'check_license',
			'license' 		=> $license_key,
			'item_name' 	=> urlencode( NNROBOTS_ADS_IN_POSTS_ITEM_NAME ), // the name of our product in EDD
			'url'       	=> is_multisite() ? network_home_url() : home_url()
		);

		// Call the custom API.

		$response = wp_remote_post( NNROBOTS_ADS_IN_POSTS_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

		// make sure the response came back okay

		if ( is_wp_error( $response ) ) {
			return false;
		}

		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		// decode the license data

		if ( isset($license_data->license) && $license_data->license == 'valid' ) {
			return true;
		} else {
			return false;
		}

	}

	/**
	 * Get the license key
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function get_license_key() {

		// Get the license key from based on WordPress install

		if ( function_exists('is_multisite') && is_multisite() ) {
			$license_key = get_site_option(self::$prefix . 'license_key');
		} else {
			$license_key = get_option(self::$prefix . 'license_key');
		}

		// Check if license key is set

		if ( $license_key === false ) {
			$license_key = '';
		}

		return $license_key;
	}

	/**
	 * Update the license key
	 *
	 * @access public
	 * @static
	 * @param mixed $license_key
	 * @return void
	 */
	static function update_license_key($license_key) {

		if ( isset( $license_key ) ) {

			// Get the license key from based on WordPress install

			if ( function_exists('is_multisite') && is_multisite() ) {

				update_site_option(self::$prefix . 'license_key', $license_key);

			} else {

				update_option(self::$prefix . 'license_key', $license_key);

			}
		}
	}

}

// Item Name

if ( !defined('NNROBOTS_ADS_IN_POSTS_ITEM_NAME') ) {
	define('NNROBOTS_ADS_IN_POSTS_ITEM_NAME', 'Ads In Posts');
}

// Store URL

if ( !defined('NNROBOTS_ADS_IN_POSTS_STORE_URL') ) {
	define('NNROBOTS_ADS_IN_POSTS_STORE_URL', 'https://99robots.com');
}

// Minimum PHP version

if ( !defined('NNROBOTS_ADS_IN_POSTS_MIN_PHP_VERSION') ) {
	define('NNROBOTS_ADS_IN_POSTS_MIN_PHP_VERSION', '5.4.0');
}

// Plugin Name

if ( !defined('NNROBOTS_ADS_IN_POSTS_PLUGIN_NAME') ) {
	define('NNROBOTS_ADS_IN_POSTS_PLUGIN_NAME', trim(dirname(plugin_basename(__FILE__)), '/'));
}

// Plugin directory

if ( !defined('NNROBOTS_ADS_IN_POSTS_PLUGIN_DIR') ) {
	define('NNROBOTS_ADS_IN_POSTS_PLUGIN_DIR', plugin_dir_path(__FILE__) );
}

// Plugin url

if ( !defined('NNROBOTS_ADS_IN_POSTS_PLUGIN_URL') ) {
	define('NNROBOTS_ADS_IN_POSTS_PLUGIN_URL', plugins_url() . '/' . NNROBOTS_ADS_IN_POSTS_PLUGIN_NAME);
}

// Plugin verison

if ( !defined('NNROBOTS_ADS_IN_POSTS_VERSION_NUM') ) {
	define('NNROBOTS_ADS_IN_POSTS_VERSION_NUM', '1.1.1');
}

// EDD Software licensing

if ( !class_exists('EDD_SL_Plugin_Updater') ) {
	include_once( dirname( __FILE__ ) . '/includes/edd-software-licensing-updates/EDD_SL_Plugin_Updater.php' );
}

add_action('wp_ajax_nnr_aip_license_action', array('NNR_Ads_In_Posts', 'license_action'));

$edd_updater = new EDD_SL_Plugin_Updater( NNROBOTS_ADS_IN_POSTS_STORE_URL , __FILE__, array(
		'version' 	=> NNROBOTS_ADS_IN_POSTS_VERSION_NUM,
		'license' 	=> NNR_Ads_In_Posts::get_license_key(),
		'item_name' => NNROBOTS_ADS_IN_POSTS_ITEM_NAME,
		'author' 	=> '99 Robots',
	)
);

endif;
